@@ -476,20 +476,19 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
             log.debug("Delay sorting because it is inhibited")
             return 0
 
-        # Sort pinned rows according to stored order
         if row1.is_pinned and row2.is_pinned:
-            if row1.position > row2.position:
-                return 1
-            return -1
+            return -1 if row1.position < row2.position else 1
 
-        # Sort pinned rows to top
-        if row1.is_pinned > row2.is_pinned:
-            return -1
-        if row2.is_pinned > row1.is_pinned:
-            return 1
+        if row1.is_pinned != row2.is_pinned:
+            return -1 if row1.is_pinned else 1
 
-        # Sort by timestamp
-        return -1 if row1.timestamp > row2.timestamp else 1
+        if row1.has_draft != row2.has_draft:
+            return -1 if row1.has_draft else 1
+
+        if row1.timestamp != row2.timestamp:
+            return -1 if row1.timestamp > row2.timestamp else 1
+
+        return 0
 
     def invalidate_sort(self, *, force: bool = False) -> bool:  # pyright: ignore
         log.debug("Try sorting chatlist")
@@ -586,6 +585,13 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
         if message.text is None:
             return
 
+        if message.type == MessageType.GROUPCHAT and message.occupant is not None:
+            client = app.get_client(event.account)
+            if client.get_module("MucBlocking").is_blocked(
+                message.remote.jid, message.occupant.id
+            ):
+                return
+
         assert message.id is not None
 
         nick = self._get_nick_for_received_message(event.account, message)
@@ -663,7 +669,7 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
                 return
             row.set_timestamp(datetime.now().astimezone())
             row.set_nick("")
-            row.set_message_text(_("Call"), icon_name="call-start-symbolic")
+            row.set_message_text(_("Call"), icon_name="lucide-phone-symbolic")
 
     def _on_file_request_received(self, event: events.FileRequestReceivedEvent) -> None:
         row = self._chats.get((event.account, event.jid))
@@ -671,7 +677,7 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
             return
         row.set_timestamp(datetime.now().astimezone())
         row.set_nick("")
-        row.set_message_text(_("File"), icon_name="text-x-generic-symbolic")
+        row.set_message_text(_("File"), icon_name="lucide-paperclip-symbolic")
 
     def _on_account_changed(self, *args: Any) -> None:
         for row in self._iterate_rows():
